@@ -3,7 +3,9 @@
 rm -rf src/*/.deps src/.deps tests/.deps
 
 case `uname` in
-Darwin) # darwin is preferred
+Darwin) # linux is preferred
+
+    echo "The repo has the stats from linux" # expect minor differences
 
     CC=gcc-mp-6 ./configure --enable-gcov=gcov-mp-6 --disable-shared --enable-unsafe \
                             --enable-norm-compat && \
@@ -11,8 +13,6 @@ Darwin) # darwin is preferred
 
 Linux)
 
-    echo "The repo has the stats from darwin" # expect minor differences
-
     ./configure --enable-gcov --disable-shared --enable-unsafe --enable-norm-compat && \
         make -s -j4 gcov ;;
 
