@@ -136,7 +136,7 @@ Linux)
             make -s -j4 check-log || exit
         make -s clean
     fi
-    for clang in clang clang-{11,10,7,5.0}
+    for clang in clang clang-{19,18,17,16,15,14,13,12,11,10,7,5.0}
     do
         if test -n `which $clang`; then
             echo $clang -march=native --disable-constraint-handler --enable-unsafe --enable-norm-compat
@@ -169,7 +169,7 @@ Linux)
     fi
     #CC="g++-6 -std=c++11" ./configure && \
         #    make -s -j4 check-log || exit
-    for gcc in gcc-{12,11,10,9,8,7,6,5}
+    for gcc in gcc-{15,14,13,12,11,10,9,8,7,6,5}
     do
         if test -n "`which $gcc`"; then
             if CC="$gcc" ./configure; then
@@ -208,6 +208,7 @@ autoreconf
 echo "--disable-wchar -f Makefile.kernel"
 ./configure --disable-wchar && \
     make -s -j4 -f Makefile.kernel || exit
+make -s -j4 -f Makefile.kernel clean
 make -s clean
 git clean -dxf src tests
 autoreconf
@@ -286,8 +287,11 @@ exit
 esac
 
 # platform independent (i.e. darwin, linux, bsd's with the 3 mingw cross compilers)
-CC="cc -m32" ./configure && \
+$make clean
+if CC="cc -m32" ./configure; then
     $make -s -j4 check-log || exit
+    $make clean
+fi
 ./configure && \
     $make -s -j4 check-log || exit
 ./configure --disable-nullslack && \
@@ -298,6 +302,34 @@ CC="cc -m32" ./configure && \
     $make -s -j4 check-log || exit
 ./configure --disable-wchar && \
     $make -s -j4 check-log || exit
+./configure --disable-float && \
+    $make -s -j4 check-log || exit
+./configure --disable-float-exp && \
+    $make -s -j4 check-log || exit
+./configure --disable-long-long && \
+    $make -s -j4 check-log || exit
+./configure --disable-long-double && \
+    $make -s -j4 check-log || exit
+./configure --disable-printf-ptrdiff && \
+    $make -s -j4 check-log || exit
+./configure --disable-doc && \
+    $make -s -j4 check-log || exit
+./configure --disable-hardening && \
+    $make -s -j4 check-log || exit
+./configure --disable-shared && \
+    $make -s -j4 check-log || exit
+./configure --enable-debug && \
+    $make -s -j4 check-log || exit
+./configure --enable-unsafe && \
+    $make -s -j4 check-log || exit
+./configure --enable-norm-compat && \
+    $make -s -j4 check-log || exit
+./configure --enable-gcov && \
+    $make -s -j4 check-log || exit
+./configure --enable-memmax=262144 && \
+    $make -s -j4 check-log || exit
+./configure --enable-strmax=2056 && \
+    $make -s -j4 check-log || exit
 ./configure --enable-warn-dmax && \
     $make -s -j4 check-log || exit
 echo configure --enable-error-dmax must fail
@@ -366,7 +398,7 @@ if [ -z "`git status --porcelain`" ]; then
         ../configure && $make check-log || exit
     cd ..
     rm -rf .build
-    
+
     echo make distcheck
     build-aux/autogen.sh && \
         ./configure && $make distcheck
@@ -378,6 +410,6 @@ rm .slkm.ko.cmd .testslkm.ko.cmd  CaseFolding.txt test-upr.pl \
    tmpfopen tmpvwscanf tmpwscanf
 rm -rf .tmp_versions/
 
-autoreconf    
+autoreconf
 ./configure --enable-unsafe --enable-debug && \
     $make -s -j4 check-log || exit
