@@ -44,8 +44,8 @@ extern "C" {
 #include "safe_types.h"
 #include "safe_compile.h"
 
-#include <stdarg.h>
 #ifndef __KERNEL__
+#include <stdarg.h>
 #include <time.h>
 #if defined HAVE_SYS_TIME_H
 #include <sys/time.h>
@@ -66,8 +66,10 @@ extern "C" {
 #define EXTERN extern
 #endif
 
-/* With this UCD version we generated our tables */
-#define SAFECLIB_UNICODE_VERSION 14
+/**
+ * With this UCD version we generated our tables
+ */
+#define SAFECLIB_UNICODE_VERSION 15
 
 /**
  * The shortest string is a null string!!
@@ -101,6 +103,9 @@ EXTERN void ignore_handler_s(const char *restrict msg, void *restrict ptr,
 /* set string constraint handler */
 EXTERN constraint_handler_t
 set_str_constraint_handler_s(constraint_handler_t handler);
+/* set thread-local constraint handler, overriding the global variant */
+EXTERN constraint_handler_t
+thrd_set_str_constraint_handler_s(constraint_handler_t handler);
 
 /* string concatenate */
 #if !defined(TEST_MSVCRT)
@@ -158,7 +163,7 @@ char * strtok_s(char *_Str,const char *_Delim,char **_Context); */
 
 /* safe sprintf_s */
 /* now __STDC_WANT_LIB_EXT1__ >= 1 compatible */
-#ifdef SAFECLIB_HAVE_C99
+#if defined(SAFECLIB_HAVE_C99) && !defined(FOR_DOXYGEN)
 EXTERN int _sprintf_s_chk(char *restrict dest, const rsize_t dmax,
                    const size_t destbos, const char *restrict fmt, ...)
    __attribute_format__(printf,4,5) BOS_CHK(dest) BOS_FMT(fmt);
@@ -177,7 +182,7 @@ EXTERN int _vsprintf_s_chk(char *restrict dest, rsize_t dmax,
     _vsprintf_s_chk(dest, dmax, BOS(dest), fmt, ap)
 
 /* truncating, no ESNOSPC */
-#if defined(SAFECLIB_HAVE_C99) && !defined(TEST_MSVCRT)
+#if defined(SAFECLIB_HAVE_C99) && !defined(TEST_MSVCRT) && !defined(FOR_DOXYGEN)
 EXTERN int _snprintf_s_chk(char *restrict dest, rsize_t dmax,
                            const size_t destbos, const char *restrict fmt, ...)
   __attribute_format__(printf,4,5) BOS_CHK(dest) BOS_FMT(fmt);
@@ -313,7 +318,7 @@ EXTERN errno_t _strcpyfld_s_chk(char *dest, const rsize_t dmax, const char *src,
 #define strcpyfld_s(dest, dmax, src, slen)                                     \
     _strcpyfld_s_chk(dest, dmax, src, slen, BOS(dest))
 
-/* copy from a null terminated string to fixed char array */
+/* copy from a zero terminated string to fixed char array */
 EXTERN errno_t _strcpyfldin_s_chk(char *dest, rsize_t dmax, const char *src,
                                   rsize_t slen, const size_t destbos)
     BOS_CHK_BUTZERO(dest, slen) BOS_OVR2_BUTZERO(src, slen)
@@ -321,7 +326,7 @@ EXTERN errno_t _strcpyfldin_s_chk(char *dest, rsize_t dmax, const char *src,
 #define strcpyfldin_s(dest, dmax, src, slen)                                   \
     _strcpyfldin_s_chk(dest, dmax, src, slen, BOS(dest))
 
-/* copy from a char array to null terminated string */
+/* copy from a char array to zero terminated string */
 EXTERN errno_t _strcpyfldout_s_chk(char *dest, rsize_t dmax, const char *src,
                                    rsize_t slen, const size_t destbos)
     BOS_CHK_BUTZERO(dest, slen) BOS_OVR2_BUTZERO(src, slen)
@@ -666,7 +671,7 @@ EXTERN int _vswprintf_s_chk(wchar_t *restrict dest, rsize_t dmax,
     _vswprintf_s_chk(dest, dmax, BOS(dest), fmt, ap)
 
 /* truncating, no ESNOSPC */
-#if defined(SAFECLIB_HAVE_C99) && !defined(TEST_MSVCRT)
+#if defined(SAFECLIB_HAVE_C99) && !defined(TEST_MSVCRT) && !defined(FOR_DOXYGEN)
 EXTERN int _snwprintf_s_chk(wchar_t *restrict dest, rsize_t dmax,
                             const size_t destbos, const wchar_t *restrict fmt,
                             ...)
