@@ -457,8 +457,8 @@ static uint8_t _combin_class(uint32_t cp) {
  * @def wcsnorm_decompose_s(dest,dmax,src,lenp,iscompat)
  * @brief
  *    Converts the wide string to the canonical NFD normalization,
- *    as defined in the latest Unicode standard, latest 10.0.  The conversion
- *    stops at the first null or after dmax characters.
+ *    as defined in the latest Unicode standard. \see SAFECLIB_UNICODE_VERSION.
+ *    The conversion stops at the first null or after dmax characters.
  *
  * @details
  *    Composed characters are checked for the left-hand-size of the
@@ -716,8 +716,8 @@ done:
  * @def wcsnorm_reorder_s(dest,dmax,src,len)
  * @brief
  *    Reorder all decomposed sequences in a wide string to NFD,
- *    as defined in the latest Unicode standard, latest 10.0. The conversion
- *    stops at the first null or after dmax characters.
+ *    as defined in the latest Unicode standard. \see SAFECLIB_UNICODE_VERSION.
+ *    The conversion stops at the first null or after dmax characters.
  *
  * @param[out]  dest      wide string to hold the result
  * @param[in]   dmax      maximum result buffer size
@@ -849,8 +849,8 @@ EXPORT errno_t _wcsnorm_reorder_s_chk(wchar_t *restrict dest, rsize_t dmax,
  * @def wcsnorm_compose_s(dest,dmax,src,lenp,iscontig)
  * @brief
  *    Combine all decomposed sequences in a wide string to NFC,
- *    as defined in the latest Unicode standard, latest 10.0. The conversion
- *    stops at the first null or after dmax characters.
+ *    as defined in the latest Unicode standard. \see SAFECLIB_UNICODE_VERSION.
+ *    The conversion stops at the first null or after dmax characters.
  *
  * @param[out]  dest      wide string to hold the result
  * @param[in]   dmax      maximum result buffer size
@@ -868,6 +868,7 @@ EXPORT errno_t _wcsnorm_reorder_s_chk(wchar_t *restrict dest, rsize_t dmax,
  * dest.
  * @retval  EOK        on success
  * @retval  ESNOSPC    when dmax too small for the result buffer
+ * @retval  ESNULLP    when dest, src or lenp are NULL
  * @retval  EOF        on some normalization error
  *
  * @see
@@ -903,12 +904,24 @@ EXPORT errno_t _wcsnorm_compose_s_chk(wchar_t *restrict dest, rsize_t dmax,
     wchar_t *orig_dest = dest;
     rsize_t orig_dmax = dmax;
 
+    if (unlikely(dest == NULL)) {
+        invoke_safe_str_constraint_handler("wcsnorm_compose_s: "
+                                           "dest is null",
+                                           dest, ESNULLP);
+        if (lenp)
+            *lenp = 0;
+        return RCNEGATE(ESNULLP);
+    }
+    if (unlikely(lenp == NULL)) {
+        handle_werror(dest, destbos / sizeof(wchar_t),
+                      "wcsnorm_compose_s: lenp is null", ESNULLP);
+        return RCNEGATE(ESNULLP);
+    }
     if (destbos == BOS_UNKNOWN) {
         if (unlikely(dmax > RSIZE_MAX_WSTR)) {
             *lenp = 0;
-            invoke_safe_str_constraint_handler("wcsnorm_compose_s: "
-                                               "dmax exceeds max",
-                                               (void *)dest, ESLEMAX);
+            handle_werror(dest, RSIZE_MAX_WSTR,
+                          "wcsnorm_compose_s: dmax exceeds max", ESLEMAX);
             return ESLEMAX;
         }
         BND_CHK_PTR_BOUNDS(dest, dmax * sizeof(wchar_t));
@@ -921,6 +934,12 @@ EXPORT errno_t _wcsnorm_compose_s_chk(wchar_t *restrict dest, rsize_t dmax,
             return EOVERFLOW;
         }
     }
+    if (unlikely(src == NULL)) {
+        *lenp = 0;
+        handle_werror(dest, destbos / sizeof(wchar_t),
+                      "wcsnorm_compose_s: src is null", ESNULLP);
+        return RCNEGATE(ESNULLP);
+    }
 
     while (p < e) {
         uint8_t cur_cc;
@@ -1033,7 +1052,8 @@ EXPORT errno_t _wcsnorm_compose_s_chk(wchar_t *restrict dest, rsize_t dmax,
 #else
     *dest = 0;
 #endif
-    *lenp = orig_dmax - dmax;
+    if (lenp)
+        *lenp = orig_dmax - dmax;
     return EOK;
 }
 
@@ -1041,8 +1061,8 @@ EXPORT errno_t _wcsnorm_compose_s_chk(wchar_t *restrict dest, rsize_t dmax,
  * @def wcsnorm_s(dest,dmax,src,mode,lenp)
  * @brief
  *    Converts the wide string to the canonical NFC or NFD normalization,
- *    as defined in the latest Unicode standard, latest 10.0.  The conversion
- *    stops at the first null or after dmax characters.
+ *    as defined in the latest Unicode standard. \see SAFECLIB_UNICODE_VERSION.
+ *    The conversion stops at the first null or after dmax characters.
  *
  * @details
  *    Decomposed characters are checked for the left-hand-size and then
