@@ -204,6 +204,7 @@ static inline void shr(size_t p[2], int n) {
         p[1] = 0;
     }
     p[0] >>= n;
+    // TODO: The result of the left shift is undefined due to shifting by '64', which is greater or equal to the width of type 'size_t'
     p[0] |= p[1] << (sizeof(size_t) * 8 - n);
     p[1] >>= n;
 }
@@ -380,8 +381,7 @@ EXPORT errno_t _qsort_s_chk(void *base, rsize_t nmemb, rsize_t size,
         if (unlikely(basesz != basebos)) {
             handle_mem_bos_chk_warn("qsort_s", (void *)base, basesz, basebos);
 #ifdef HAVE_ERROR_DMAX
-            errno = ESLEWRNG;
-            return NULL;
+            return RCNEGATE(ESLEWRNG);
 #endif
         }
 #endif
