@@ -3,6 +3,7 @@
  *
  * September 2017, Reini Urban
  * January 2022, Reini Urban
+ * October 2022, Reini Urban
  *
  * Copyright (c) 2017,2022 by Reini Urban
  * All rights reserved.
@@ -51,7 +52,7 @@
  *    is written to *len (unless null) and '\0' is written to value[0] (unless
  *    null).
  *    With SAFECLIB_STR_NULL_SLACK defined all elements following the
- *    terminating null character (if any) written in the
+ *    terminating NUL character (if any) written in the
  *    array of dmax characters pointed to by dest are nulled.
  *    If \c secure_getenv() is available, it is used.
  *
@@ -62,6 +63,9 @@
  *
  * @param[out] len    pointer to a size_t where getenv_s will store the length
  *                    of the found environment variable. Might be NULL.
+ *                    Note that on Microsoft Windows we return len+1, the
+ *                    size of the buffer, including the terminating NUL, to match
+ *                    the wrong getenv_s implementation und usages in the wild there.
  * @param[out] dest   pointer to a string where getenv_s will store the
  *                    contents of the found environment variable. Might be NULL.
  * @param[in]  dmax   maximum number of characters that getenv_s is allowed
@@ -99,16 +103,42 @@ EXPORT errno_t _getenv_s_chk(size_t *restrict len, char *restrict dest,
     const char *buf;
     size_t len1;
 
-    if (destbos == BOS_UNKNOWN) {
-        CHK_DMAX_MAX("getenv_s", RSIZE_MAX_STR)
-        BND_CHK_PTR_BOUNDS(dest, dmax);
-    } else {
-        CHK_DEST_OVR("getenv_s", destbos)
+    if (likely(dest)) {
+        if (destbos == BOS_UNKNOWN) {
+            if (unlikely(dmax > RSIZE_MAX_STR)) {
+                goto err_dmax;
+            }
+            BND_CHK_PTR_BOUNDS(dest, dmax);
+        } else {
+            if (unlikely(dmax > destbos)) {
+            err_dmax:
+                if (len)
+                    *len = 0;
+                invoke_safe_str_constraint_handler("getenv_s: dmax exceeds max",
+                                                   (void *)dest, ESLEMAX);
+                return RCNEGATE(ESLEMAX);
+            }
+        }
+    }
+    else {
+        if (dmax != 0) { // with dest == NULL
+            if (len)
+                *len = 0;
+            invoke_safe_str_constraint_handler("getenv_s: dmax must be 0",
+                                               NULL, ESNULLP);
+            return ESNULLP;
+        }
     }
     if (unlikely(name == NULL)) {
         if (len)
             *len = 0;
-        handle_error(dest, dmax, "getenv_s: name is null", ESNULLP);
+        if (likely(dest)) {
+            handle_error(dest, dmax, "getenv_s: name is null", ESNULLP);
+        }
+        else {
+            invoke_safe_str_constraint_handler("getenv_s: name is null",
+                                               NULL, ESNULLP);
+        }
         return ESNULLP;
     }
 
@@ -119,12 +149,16 @@ EXPORT errno_t _getenv_s_chk(size_t *restrict len, char *restrict dest,
     buf = getenv(name);
 #endif
 
-    if (unlikely(buf == NULL)) {
-        char errstr[128] = "getenv_s: ";
+    if (buf == NULL) {
+        if (likely(dest)) {
+#ifdef SAFECLIB_STR_NULL_SLACK
+            memset(dest, 0, dmax);
+#else
+            *dest = '\0';
+#endif
+        }
         if (len)
             *len = 0;
-        strcat(errstr, strerror(errno));
-        handle_error(dest, dmax, errstr, -1);
         return -1;
     }
 
@@ -134,10 +168,15 @@ EXPORT errno_t _getenv_s_chk(size_t *restrict len, char *restrict dest,
             *len = 0;
         handle_error(dest, dmax, "getenv_s: dmax is too small", ESNOSPC);
         return RCNEGATE(ESNOSPC);
-    } else if (dest) {
+    } else {
         if (len)
+#ifdef _WIN32
+            *len = len1 + 1;
+#else
             *len = len1;
-        strcpy_s(dest, dmax, buf);
+#endif
+        if (dest)
+            strcpy_s(dest, dmax, buf);
     }
 
     return EOK;
