@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------
  * test_towupper.c
  *
- * Test the musl-inherited towupper regarding latest Unicode 13.0
+ * Test the musl-inherited towupper regarding latest Unicode 15.0
  * Unicode has no explicit lower->upper mapping document.
  *
  *------------------------------------------------------------------
@@ -27,14 +27,10 @@ int test_towupper(void);
 
 #define GENCAT "DerivedGeneralCategory.txt"
 #define CFOLD "CaseFolding.txt"
-#ifndef PERL
 /* Must have the same Unicode version 9.0, at least 5.26.
-   Better 5.27.3 with Unicode 10, 5.30 with 12.1, 5.32 with 13.0, 5.34 with 14.0
+   Better 5.27.3 with Unicode 10, 5.30 with 12.1, 5.32 with 13.0, 5.34 with 14.0,
+   5.37.4-5.40 with 15.0
  */
-/*# define PERL "perl" */
-/*# define PERL "cperl5.30.0"*/
-#define PERL "perl5.36.0"
-#endif
 #define TESTPL "test-upr.pl"
 
 char s[128];
@@ -82,13 +78,18 @@ int check_casefolding(uint32_t lwr, uint32_t upr) {
                 if (*status != 'F') {
                     /* false positives */
                     debug_printf(
-                        "%u U+%04X: U+%04X != U+%04X status=%s, name=%s\n",
-                        __LINE__, wc, lwr, mp, status, name);
+                      "cross-check U+%04X: U+%04X != U+%04X status=%s, name=%s:\n",
+                      wc, lwr, mp, status, name);
                     /* cross-check with perl */
                     if (!init) {
-                        fprintf(pl, "use v5.31.8;\n");
+                        fprintf(pl, "use v%s;\n", PERL_VERSION);
                         fprintf(pl, "use Unicode::UCD;\n");
-                        fprintf(pl, "print Unicode::UCD::UnicodeVersion(), \" must be 13.0.0\\n\";\n");
+                        fprintf(pl,
+                                "warn \"Unicode::UCD::UnicodeVersion() must be "
+                                "%d.0.0\" if Unicode::UCD::UnicodeVersion() ne "
+                                "\"%d.0.0\";\n",
+                                SAFECLIB_UNICODE_VERSION,
+                                SAFECLIB_UNICODE_VERSION);
                         fprintf(pl, "my ($l,$u,$got);\n");
                         init = 1;
                     }
@@ -152,10 +153,13 @@ int test_towupper(void) {
     pl = fopen(TESTPL, "w");
     f = fopen(GENCAT, "r");
     if (!f) {
-        printf("downloading %s ...", GENCAT);
+        char url[256];
+        snprintf(url, 255,
+                 "wget https://www.unicode.org/Public/%d.0.0/ucd/extracted/%s",
+                 SAFECLIB_UNICODE_VERSION, GENCAT);
+        printf("downloading %s via %s ...", GENCAT, url);
         fflush(stdout);
-        if (system("wget https://www.unicode.org/Public/14.0.0/ucd/extracted/"
-                   "DerivedGeneralCategory.txt"))
+        if (system(url))
             printf(" done\n");
         else {
             printf(" failed\n");
@@ -168,9 +172,13 @@ int test_towupper(void) {
 
     cf = fopen(CFOLD, "r");
     if (!cf) {
-        printf("downloading %s ...", CFOLD);
+        char url[256];
+        snprintf(url, 255,
+                 "wget https://www.unicode.org/Public/%d.0.0/ucd/%s",
+                 SAFECLIB_UNICODE_VERSION, CFOLD);
+        printf("downloading %s via %s ...", CFOLD, url);
         fflush(stdout);
-        if (system("wget https://www.unicode.org/Public/14.0.0/ucd/CaseFolding.txt"))
+        if (system(url))
             printf(" done\n");
         else {
             printf(" failed\n");
