@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------
  * test_vsnprintf_s
  * File 'wchar/vsnprintf_s.c'
- * Lines executed:40.12% of 486
+ * Lines executed:77.63% of 617
  *
  *------------------------------------------------------------------
  */
@@ -158,7 +158,7 @@ int test_vsnprintf_s(void) {
     if (len3 != len2) {
 #ifdef DEBUG
         int len1 = strlen(str1);
-        debug_printf("%s %u lengths wrong: %d  %u  %u \n", __FUNCTION__,
+        debug_printf("%s %u lengths wrong: %d  %"PRId32"  %"PRId32" \n", __FUNCTION__,
                      __LINE__, len1, len2, len3);
 #endif
         errs++;
