@@ -9,12 +9,45 @@
 #include "test_private.h"
 #include "safe_str_lib.h"
 #include <stdarg.h>
+#include <wchar.h>
+#include <float.h>
+#include <math.h>
 #if defined(TEST_MSVCRT) && defined(HAVE_VSPRINTF_S)
 #undef vsprintf_s
 EXTERN int vsprintf_s(char *restrict dest, rsize_t dmax,
                       const char *restrict fmt, va_list ap);
 #endif
 
+// support for the floating point type (%f)
+// default: activated
+#ifndef PRINTF_DISABLE_SUPPORT_FLOAT
+#define PRINTF_SUPPORT_FLOAT
+#endif
+
+#ifdef PRINTF_INCLUDE_CONFIG_H
+#include "printf_config.h"
+#endif
+
+// support for the long long types (%llu or %p)
+// default: activated
+#ifndef PRINTF_DISABLE_SUPPORT_LONG_LONG
+# ifdef HAVE_LONG_LONG
+#  define PRINTF_SUPPORT_LONG_LONG
+# else
+#  undef PRINTF_SUPPORT_LONG_LONG
+# endif
+#endif
+
+// support for the long double types (%Lf %Le %Lg %La)
+// default: probed
+#ifndef PRINTF_DISABLE_SUPPORT_LONG_DOUBLE
+# ifdef HAVE_LONG_DOUBLE
+#  define PRINTF_SUPPORT_LONG_DOUBLE
+# else
+#  undef PRINTF_SUPPORT_LONG_DOUBLE
+# endif
+#endif
+
 //#ifdef HAVE_VSPRINTF_S
 //#define HAVE_NATIVE 1
 //#else
@@ -26,6 +59,7 @@ EXTERN int vsprintf_s(char *restrict dest, rsize_t dmax,
 
 static char str1[LEN];
 static char str2[LEN];
+static wchar_t wstr[LEN];
 static inline int vtprintf_s(char *restrict dest, rsize_t dmax,
                              const char *restrict fmt, ...);
 int test_vsprintf_s(void);
@@ -141,7 +175,7 @@ int test_vsprintf_s(void) {
     if (len3 != len2) {
 #ifdef DEBUG
         int len1 = strlen(str1);
-        debug_printf("%s %u lengths wrong: %d  %u  %u \n", __FUNCTION__,
+        debug_printf("%s %u lengths wrong: %d  %"PRId32"  %"PRId32" \n", __FUNCTION__,
                      __LINE__, len1, len2, len3);
 #endif
         errs++;
@@ -271,6 +305,96 @@ int test_vsprintf_s(void) {
 
     /*--------------------------------------------------*/
 
+#ifndef SAFECLIB_DISABLE_WCHAR
+    rc = vtprintf_s(str1, LEN, "%lc", L'A');
+    NOERR()
+    EXPSTR(str1, "A");
+
+    wcscpy(wstr, L"AB");
+    rc = vtprintf_s(str1, LEN, "%ls", wstr);
+    NOERR()
+    EXPSTR(str1, "AB");
+#endif
+
+#ifdef PRINTF_SUPPORT_FLOAT
+    rc = vtprintf_s(str1, LEN, "%f", 0.0f);
+    NOERR()
+    EXPSTR(str1, "0.000000");
+
+    rc = vtprintf_s(str1, LEN, "%lf", 0.0);
+    NOERR()
+    EXPSTR(str1, "0.000000");
+    rc = vtprintf_s(str1, LEN, "%llf", 0.0);
+    NOERR()
+    EXPSTR(str1, "0.000000");
+#ifdef PRINTF_SUPPORT_EXPONENTIAL
+    rc = vtprintf_s(str1, LEN, "%a", 0.0);
+    NOERR()
+    EXPSTR(str1, "0x0p+0");
+    rc = vtprintf_s(str1, LEN, "%A", 0.0);
+    NOERR()
+    EXPSTR(str1, "0X0P+0");
+#endif
+#ifdef PRINTF_SUPPORT_LONG_DOUBLE
+    rc = vtprintf_s(str1, LEN, "%Lf", 0.0L);
+    NOERR()
+    EXPSTR(str1, "0.000000");
+    rc = vtprintf_s(str1, LEN, "long >%Lf<", 0.0L);
+    NOERR()
+    EXPSTR(str1, "long >0.000000<");
+#ifdef PRINTF_SUPPORT_EXPONENTIAL
+    rc = vtprintf_s(str1, LEN, "long >%La<", 0.0L);
+    NOERR()
+    EXPSTR(str1, "long >0x0p+0<");
+    rc = vtprintf_s(str1, LEN, "long >%LA<", 0.0L);
+    NOERR()
+    EXPSTR(str1, "long >0X0P+0<");
+#endif
+#endif
+
+    {
+        union {
+            uint64_t L;
+            uint32_t U[2]; // always 8 byte
+            double F;
+        } c32;
+        union {
+            uint64_t U[2]; // 10-16 bytes
+            long double F;
+        } c64;
+        c32.U[0] = -1;
+        c32.U[1] = -1;
+        c64.U[0] = -1;
+        c64.U[1] = -1;
+
+        rc = vtprintf_s(str1, LEN, "%f", c32.F);
+        NOERR()
+        EXPSTR(str1, "nan");
+#ifdef PRINTF_SUPPORT_LONG_DOUBLE
+        rc = vtprintf_s(str1, LEN, "%LF", c64.F);
+        NOERR()
+        EXPSTR(str1, "NAN");
+#endif
+        rc = vtprintf_s(str1, LEN, "%f", INFINITY);
+        NOERR()
+        EXPSTR(str1, "inf"); // 6.926406461289696e-310
+        rc = vtprintf_s(str1, LEN, "%f", -INFINITY);
+        NOERR()
+        EXPSTR_OR(str1, "-inf", "inf"); // "inf" on BSD/mingw
+
+#ifdef PRINTF_SUPPORT_LONG_DOUBLE
+        rc = vtprintf_s(str1, LEN, "%LF", HUGE_VALL);
+        NOERR()
+        EXPSTR(str1, "INF");
+        rc = vtprintf_s(str1, LEN, "%LF", -HUGE_VALL);
+        NOERR()
+        EXPSTR(str1, "-INF");
+#endif
+    }
+#endif
+
+    /*--------------------------------------------------*/
+
     return (errs);
 }
 
