@@ -1,7 +1,7 @@
 /*------------------------------------------------------------------
  * test_wcsnorm_s
  * File 'wcsnorm_s.c'
- * Lines executed:79.40% of 364
+ * Lines executed:78.25% of 377
  *
  *------------------------------------------------------------------
  */
@@ -22,15 +22,10 @@ EXTERN uint32_t _dec_w16(wchar_t *src);
 #endif
 int test_wcsnorm_s(void);
 
-/*#define PERL_TEST*/
+#define PERL_TEST
 /* Must have the same Unicode version 10, since 5.27.3
    perl -MUnicode::UCD -e'print Unicode::UCD::UnicodeVersion()'
 */
-#ifndef PERL
-/*# define PERL "perl" */
-/*# define PERL "cperl5.30.0" */
-#define PERL "perl5.36.0"
-#endif
 #define TESTPL "test-norm.pl"
 
 int test_wcsnorm_s(void) {
@@ -558,19 +553,19 @@ int test_wcsnorm_s(void) {
         {
             size_t i;
             /* cross-check with perl */
-            fprintf_s(pl, "$err += chknfd (\"\\N{U+%04X}\",\"\\N{U+%04X}", ind,
-                      str[0]);
+            fprintf_s(pl, "$err += chknfd (\"\\N{U+%04X}\",\"\\N{U+%04X}", (unsigned)ind,
+                      (unsigned)str[0]);
             for (i = 1; i < len; i++) {
-                fprintf_s(pl, "\\N{U+%04X}", str[i]);
+                fprintf_s(pl, "\\N{U+%04X}", (unsigned)str[i]);
             }
             fprintf_s(pl, "\");\n");
 
 #ifdef HAVE_NORM_COMPAT
             rc = wcsnorm_s(str, LEN, src, WCSNORM_NFKD, &len);
-            fprintf_s(pl, "$err += chknfkd(\"\\N{U+%04X}\",\"\\N{U+%04X}", ind,
-                      str[0]);
+            fprintf_s(pl, "$err += chknfkd(\"\\N{U+%04X}\",\"\\N{U+%04X}", (unsigned)ind,
+                      (unsigned)str[0]);
             for (i = 1; i < len; i++) {
-                fprintf_s(pl, "\\N{U+%04X}", str[i]);
+                fprintf_s(pl, "\\N{U+%04X}", (unsigned)str[i]);
             }
             fprintf_s(pl, "\");\n");
 #endif
